summaryrefslogtreecommitdiff
path: root/source4/pidl/lib
diff options
context:
space:
mode:
Diffstat (limited to 'source4/pidl/lib')
-rw-r--r--source4/pidl/lib/Parse/Pidl/Wireshark/Conformance.pm (renamed from source4/pidl/lib/Parse/Pidl/Ethereal/Conformance.pm)12
-rw-r--r--source4/pidl/lib/Parse/Pidl/Wireshark/NDR.pm (renamed from source4/pidl/lib/Parse/Pidl/Ethereal/NDR.pm)14
2 files changed, 13 insertions, 13 deletions
diff --git a/source4/pidl/lib/Parse/Pidl/Ethereal/Conformance.pm b/source4/pidl/lib/Parse/Pidl/Wireshark/Conformance.pm
index e7f2922c7f..93927f8f54 100644
--- a/source4/pidl/lib/Parse/Pidl/Ethereal/Conformance.pm
+++ b/source4/pidl/lib/Parse/Pidl/Wireshark/Conformance.pm
@@ -1,5 +1,5 @@
###################################################
# parse an ethereal conformance file
# Copyright jelmer@samba.org 2005
# released under the GNU GPL
@@ -7,15 +7,15 @@
=head1 NAME
-Parse::Pidl::Ethereal::Conformance - Conformance file parser for Ethereal
+Parse::Pidl::Wireshark::Conformance - Conformance file parser for Wireshark
=head1 DESCRIPTION
-This module supports parsing Ethereal conformance files (*.cnf).
+This module supports parsing Wireshark conformance files (*.cnf).
=head1 FILE FORMAT
-Pidl needs additional data for ethereal output. This data is read from
+Pidl needs additional data for Wireshark output. This data is read from
so-called conformance files. This section describes the format of these
files.
@@ -59,7 +59,7 @@ Remove the specified prefix from all function names (if present).
=item I<PROTOCOL> longname shortname filtername
Change the short-, long- and filter-name for the current interface in
-Ethereal.
+Wireshark.
=item I<FIELD_DESCRIPTION> field desc
@@ -89,7 +89,7 @@ ett/hf variables for a particular element as the NOEMIT command does.
=cut
-package Parse::Pidl::Ethereal::Conformance;
+package Parse::Pidl::Wireshark::Conformance;
require Exporter;
use vars qw($VERSION);
@@ -1,5 +1,5 @@
###################################################
-# parse an ethereal conformance file
+# parse an Wireshark conformance file
# Copyright jelmer@samba.org 2005
# released under the GNU GPL
diff --git a/source4/pidl/lib/Parse/Pidl/Ethereal/NDR.pm b/source4/pidl/lib/Parse/Pidl/Wireshark/NDR.pm
index 685cb5a12a..872a149274 100644
--- a/source4/pidl/lib/Parse/Pidl/Ethereal/NDR.pm
+++ b/source4/pidl/lib/Parse/Pidl/Wireshark/NDR.pm
@@ -10,18 +10,18 @@
=head1 NAME
-Parse::Pidl::Ethereal::NDR - Parser generator for Ethereal
+Parse::Pidl::Wireshark::NDR - Parser generator for Wireshark
=cut
-package Parse::Pidl::Ethereal::NDR;
+package Parse::Pidl::Wireshark::NDR;
use strict;
use Parse::Pidl::Typelist qw(getType);
use Parse::Pidl::Util qw(has_property ParseExpr property_matches make_str);
use Parse::Pidl::NDR qw(ContainsString GetNextLevel);
use Parse::Pidl::Dump qw(DumpTypedef DumpFunction);
-use Parse::Pidl::Ethereal::Conformance qw(ReadConformance);
+use Parse::Pidl::Wireshark::Conformance qw(ReadConformance);
use File::Basename;
use vars qw($VERSION);
@@ -822,7 +822,7 @@ sub Initialize($)
}
#####################################################################
# Generate ethereal parser and header code
sub Parse($$$$)
{
my($ndr,$idl_file,$h_filename,$cnf_file) = @_;
@@ -841,9 +841,9 @@ sub Parse($$$$)
from $idl_file and $cnf_file.
Pidl is a perl based IDL compiler for DCE/RPC idl files.
- It is maintained by the Samba team, not the Ethereal team.
+ It is maintained by the Samba team, not the Wireshark team.
Instructions on how to download and install Pidl can be
- found at http://wiki.ethereal.com/Pidl
+ found at http://wiki.wireshark.org/Pidl
*/
";
@@ -867,7 +867,7 @@ sub Parse($$$$)
$res{headers} .= "#include \"$h_basename\"\n";
pidl_code "";
# Ethereal protocol registration
ProcessInterface($_) foreach (@$ndr);
@@ -822,7 +822,7 @@ sub Initialize($)
}
#####################################################################
-# Generate ethereal parser and header code
+# Generate Wireshark parser and header code
sub Parse($$$$)
{
@@ -867,7 +867,7 @@ sub Parse($$$$)
$res{headers} .= "#include \"$h_basename\"\n";
pidl_code "";
- # Ethereal protocol registration
+ # Wireshark protocol registration
ProcessInterface($_) foreach (@$ndr);